@@ -17,13 +17,27 @@
 
 import sys, os
 from calculate.lib.utils.common import getpass
+from calculate.lib.cl_print import color_print
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_core',sys.modules[__name__])
 
+colorPrint = color_print()
+
 def _print (*args):
     print " ".join(map(lambda x:unicode(x).encode('utf-8'),args))
 
-def get_password(text1 = None, text2 = None):
+def get_password(text1 = None, text2 = None, getfromstdin=False):
+    if getfromstdin:
+        try:
+            passwd = ''
+            while not passwd:
+                passwd = sys.stdin.readline()
+                if not passwd:
+                    return None
+                passwd = passwd.rstrip('\n')
+            return passwd
+        except:
+            return None
     if not text1:
         text1 = _('Password: ')
     if not text2:
@@ -94,6 +108,14 @@ class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
         return _textwrap.wrap(text.decode('utf-8'), width)
 
 def get_method_argparser(view, args, cl_core = False):
+    """
+    Get argparser by ViewInfo get from WSDL server (or stub)
+
+    cl_core  - argparser for cl_core (local call)
+    """
+    # get list (local View) or first element of tuple (WSDL View)
+    getlist = (lambda x:x) if cl_core else (lambda x:x[0])
+    error_flag = False
     method = args.method
     if cl_core:
         progr = os.path.basename(sys.argv[0])
@@ -102,86 +124,43 @@ def get_method_argparser(view, args, cl_core = False):
 
     parser = argparse.ArgumentParser(prog=progr, add_help=False,
                                  formatter_class=RawAndDefaultsHelpFormatter)
-#    parser = argparse.ArgumentParser(prog=progr, add_help=False)
-    if type(view.groups) == list:
-        # for local call method
-        groups = view.groups
-    else:
-        groups = view.groups[0]
 
-    for Group in groups:
+    for Group in getlist(view.groups):
         if not Group.fields:
             continue
         group = parser.add_argument_group(Group.name)
-        if type(Group.fields) == list:
-            # for local call method
-            fields = Group.fields
-        else:
-            fields = Group.fields[0]
-        for field in fields:
+        for field in getlist(Group.fields):
             if field.element == 'error':
-	        print field.label
+                error_flag = True
+                colorPrint.printERROR(field.label)
             elif field.opt:
-                action = None
-                arg_type = str
-                if field.element in ['check', 'check_tristate']:
-                    arg_type = bool
-                elif field.element == 'radio' and field.type == 'bool':
-                    arg_type = bool
-                elif field.element == 'table' and field.type != 'steps':
-                    action = 'append'
-
                 opt = field.opt
-                metavalue = opt.metavalue if opt.metavalue \
-                                          else field.name.upper()
-
-                if ':' in metavalue:
-                    metavalue = field.name.upper()
+                data = {'dest':field.name,'help' : opt.help}
+                if field.type == "password":
+                    data['action'] = "store_true"
+                else:
+                    data['type'] = str
+                if field.element == 'table' and field.type != 'steps':
+                    data['action'] = 'append'
 
+                if data.get('action') != "store_true":
+                    data['metavar'] = opt.metavalue if opt.metavalue \
+                                              else field.name.upper()
+                    if ':' in data['metavar']:
+                        data['metavar'] = field.name.upper()
                 try:
-                    if arg_type == str:
-                        if opt.shortopt and opt.longopt:
-                            group.add_argument(opt.shortopt, opt.longopt,
-                                 type = arg_type, dest=field.name, metavar = \
-                                 metavalue, action = action, help = opt.help)
-                        elif opt.shortopt and not opt.longopt:
-                            group.add_argument(opt.shortopt,
-                                 type = arg_type, dest=field.name, metavar = \
-                                 metavalue, action = action, help = opt.help)
-                        elif opt.longopt and not opt.shortopt:
-                            group.add_argument(opt.longopt,
-                                 type = arg_type, dest=field.name, metavar = \
-                                 metavalue, action = action, help = opt.help)
-
-#                    elif arg_type == bool:
-#                        if opt.shortopt and opt.longopt:
-#                            group.add_argument(opt.shortopt, opt.longopt,
-#                                        action='store_true', dest=field.name,
-#                                        default=None, help = opt.help)
-#                        elif opt.shortopt and not opt.longopt:
-#                            group.add_argument(opt.shortopt,
-#                                        action='store_true', dest=field.name,
-#                                        default=None, help = opt.help)
-#                        elif opt.longopt and not opt.shortopt:
-#                            group.add_argument(opt.longopt,
-#                                        action='store_true', dest=field.name,
-#                                        default=None, help=opt.help)
-                    elif arg_type == bool:
-                        if opt.shortopt and opt.longopt:
-                            group.add_argument(opt.shortopt, opt.longopt,
-                                        type = str, dest=field.name,
-                                        help = opt.help)
-                        elif opt.shortopt and not opt.longopt:
-                            group.add_argument(opt.shortopt, type = str,
-                                               dest=field.name, help=opt.help)
-                        elif opt.longopt and not opt.shortopt:
-                            group.add_argument(opt.longopt, type = str,
-                                               dest=field.name, help=opt.help)
+                    opts = filter(None,[opt.shortopt,opt.longopt])
+                    group.add_argument(*opts,**data)
                 except argparse.ArgumentError:
                     continue
+    if error_flag:
+        raise Exception
     return parser
 
 def set_obj_item(client, param_object, field_name, value):
+    """
+    Set value for Info object. By client detect (local or WSDL call)
+    """
     if client:
         param_object.__setitem__(field_name, value)
     else:
@@ -306,12 +285,13 @@ def check_result_msg(method_result, view, input_error_dict = {}):
                 if field.name == error.field:
                     if field.opt.shortopt or field.opt.longopt:
                         params_text += _('Wrong option ')
-                        params_text += ', '.join(filter(None,
+                        params_text += ' '+', '.join(filter(None,
                             [field.opt.shortopt, field.opt.longopt])) \
                             + '. '
 
-        red = '\033[31m * \033[0m'
-        _print ('\r' + red + params_text + error.message)
+        sys.stdout.write('\r')
+        sys.stdout.flush()
+        colorPrint.printERROR(params_text + error.message)
 
     if len(password_errors) < len(method_result):
         return None
@@ -323,7 +303,8 @@ def check_result_msg(method_result, view, input_error_dict = {}):
             return None
         return password_errors
 
-def get_param_pwd(check_res, view, param_object, client = None):
+def get_param_pwd(check_res, view, param_object, client = None,
+                  stdin_passwd=False):
     if hasattr (view.groups, 'GroupField'):
         groups = view.groups.GroupField
     else:
@@ -338,18 +319,22 @@ def get_param_pwd(check_res, view, param_object, client = None):
             for field in fields:
                 if field.name == pwd_field:
                     if field.element == 'table':
-                        value = get_password()
+                        value = get_password(getfromstdin=stdin_passwd)
                         if value == None:
                             raise KeyboardInterrupt
                         set_table_pwd(client, param_object, field, value)
                     else:
-                        value = get_password()
+                        value = get_password(getfromstdin=stdin_passwd)
                         if value == None:
                             raise KeyboardInterrupt
                         setattr(param_object, pwd_field, value)
     return param_object
 
-def collect_object(client, param_object, view, args, wait_thread = None):
+def collect_object(client, param_object, view, args,wait_thread = None,
+                   stdin_passwd = False):
+    """
+    Collect Info object by args
+    """
     steps = None
     if type(view.groups) == list:
         # for local call method
@@ -413,10 +398,20 @@ def collect_object(client, param_object, view, args, wait_thread = None):
                                             val)
 
             elif field.element in ['input', 'openfile',\
-                                   'file', 'password', 'radio']:
+                                   'file', 'radio']:
                 param_object = set_obj_item(client, param_object, field.name,
                                             _getattr(args, field.name))
-
+            elif field.element in ['password'] and _getattr(args, field.name):
+                if wait_thread:
+                    wait_thread.pause()
+                password=get_password("%s: "%field.label,_('Repeat password: '),
+                                      getfromstdin=stdin_passwd)
+                if password is None:
+                    raise KeyboardInterrupt
+                param_object = set_obj_item(client, param_object, field.name,
+                                            password)
+                if wait_thread:
+                    wait_thread.resume()
             elif field.element in ['combo', 'comboEdit']:
                 value = _getattr(args, field.name)
                 if value:
@@ -448,7 +443,8 @@ def collect_object(client, param_object, view, args, wait_thread = None):
 
             elif field.element == 'table' and field.type != 'steps':
                 val = _getattr(args, field.name)
-                value = collect_table(field, val, client, wait_thread)
+                value = collect_table(field, val, client, wait_thread,
+                                      stdin_passwd)
                 param_object = set_obj_item(client, param_object, field.name,
                                             value)
 
@@ -459,7 +455,8 @@ def collect_object(client, param_object, view, args, wait_thread = None):
 
     return param_object, steps
 
-def collect_table(field, val_list, client, wait_thread = None):
+def collect_table(field, val_list, client, wait_thread = None,
+                  stdin_passwd = False):
     if not val_list:
         return None
     val_table = map(lambda x: x.split(':'), val_list)
@@ -500,7 +497,8 @@ def collect_table(field, val_list, client, wait_thread = None):
                     sys.stdout.write('\r')
                     sys.stdout.flush()
                 password=get_password(_('Password for %s: ')%val_table[i][0],\
-                               _('Repeat password for %s: ') %val_table[i][0])
+                               _('Repeat password for %s: ') %val_table[i][0],
+                               getfromstdin=stdin_passwd)
                 if password == None:
                     raise KeyboardInterrupt
         temp_row = []
