@@ -220,6 +220,11 @@ def cout_progress(string = None):
     sys.stdout.flush()
 
 def local_method(metaclass, args):
+    """
+    Call method from metaclass, check method existing.
+
+    Generate help, for method, run method by 'call_method'.
+    """
     import os
     sym_link = os.path.basename(sys.argv[0])
     if sym_link != 'cl-core':
@@ -250,18 +255,29 @@ def local_method(metaclass, args):
             view = getattr(metaObject, method_view_name)(0, view_obj)
         except AttributeError:
             colorPrint.printERROR (_('Method not found: '), method_view_name)
-        method_parser = get_method_argparser(view, args, cl_core = True)
+
+        try:
+            method_parser = get_method_argparser(view, args, cl_core = True)
+        except Exception as e:
+            metaObject.clear_cache(0, method_name)
+            return  1
         method_parser.print_help()
     else:
         try:
             call_method(metaObject, args, colorPrint)
         except (KeyboardInterrupt, EOFError):
             colorPrint.printERROR(_('Interrupted by the user'))
+        except Exception:
+            pass
 #            print 'Error: ', e
     metaObject.clear_cache(0, method_name)
 
 def call_method(metaObject, args, colorPrint):
+    """
+    Function for call method through metaObject and args
+    """
     method_name = args.method
+    stdin_passwd = args.stdin_passwd
     method_view_name = method_name + '_view'
     metaObject.no_progress = args.no_progress
     view_obj = ViewInfo()
@@ -287,7 +303,8 @@ def call_method(metaObject, args, colorPrint):
                 _print (_('Unknown parameter'), i)
                 return 1
 
-    param_object, steps = collect_object(None, param_object, view, args)
+    param_object, steps = collect_object(None, param_object, view, args,
+                                         stdin_passwd=stdin_passwd)
     if view.has_brief:
         setattr(param_object, 'CheckOnly', True)
         check_res = {}
@@ -303,7 +320,8 @@ def call_method(metaObject, args, colorPrint):
                     return None
                 else:
                     param_object = get_param_pwd(check_res, view,
-                                                 param_object)
+                                                 param_object,
+                                                 stdin_passwd=stdin_passwd)
             else:
                 break
 
@@ -366,9 +384,17 @@ def create_param_object(view):
             param_object._type_info[field.name] = None
     return param_object
 
+def print_brief(view, brief_label):
+    for Group in view.groups:
+        if Group.name:
+            if not Group.fields:
+                continue
+        print_brief_group(Group.fields, Group.name)
+
 def print_brief_group(Fields, group_name):
-    if group_name:
-        _print ('\b'+group_name)
+    print_group_flag = False
+#    if group_name:
+#        _print ('\b'+group_name)
     uncompatible_count = 0
     colorPrint = color_print()
     for field in Fields:
@@ -377,6 +403,10 @@ def print_brief_group(Fields, group_name):
             continue
         if field.element in ['input', 'openfile']:
             value = field.value if field.value else ''
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printSUCCESS('%s: %s' %(field.label, value))
 
         elif field.element in ['combo', 'comboEdit', 'radio', 'file']:
@@ -396,6 +426,10 @@ def print_brief_group(Fields, group_name):
                 value = ', '.join(value)
             else:
                 value = field.value if field.value else ''
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printSUCCESS('%s: %s' %(field.label, value))
 
         elif field.element in ['multichoice', 'multichoice_add',\
@@ -422,12 +456,20 @@ def print_brief_group(Fields, group_name):
                 value = ', '.join(field.listvalue)
             elif not value:
                 value = field.value if field.value else ''
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printSUCCESS('%s: %s' %(field.label, value))
 
 #        elif field.element == 'label':
 #            print field.label
 
         elif field.element == 'error':
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printERROR(field.label)
 
         elif field.element in ['check', 'check_tristate']:
@@ -439,6 +481,10 @@ def print_brief_group(Fields, group_name):
                 value = _('auto')
             else:
                 value = field.value
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printSUCCESS('%s: %s' %(field.label, value))
 
         elif field.element == 'table' and field.type != 'steps':
@@ -474,6 +520,10 @@ def print_brief_group(Fields, group_name):
             data = []
             for body_row in body:
                 data.append(map(lambda x: x if x else '', body_row))
+            if not print_group_flag:
+                if group_name:
+                    print_group_flag = True
+                    _print ('\b'+group_name)
             colorPrint.printSUCCESS(field.label+': ')
             res = printTable(data, head)
             sys.stdout.flush()
@@ -481,15 +531,8 @@ def print_brief_group(Fields, group_name):
         else:
             uncompatible_count += 1
 
-    if uncompatible_count == len (Fields) and group_name:
-        colorPrint.printSUCCESS(_('Not used'))
-
-def print_brief(view, brief_label):
-    for Group in view.groups:
-        if Group.name:
-            if not Group.fields:
-                continue
-        print_brief_group(Group.fields, Group.name)
+#    if uncompatible_count == len (Fields) and group_name:
+#        colorPrint.printSUCCESS(_('Not used'))
 
 def printTable(data, header=None ):
     res = []
